@@ -37,7 +37,12 @@
 #include <unistd.h>
 #include <sys/ioctl.h>
 #include <sys/soundcard.h>
+
+#ifdef __STDC__
+#include <curses.h>
+#else
 #include <ncurses.h>
+#endif
 
 #define BG_COLOR 1
 #define TITLE_COLOR 2
