@@ -6,7 +6,7 @@
 /*	    Liam Corner - zenith@dcs.warwick.ac.uk			*/
 /*	    Marc Espie - espie@dmi.ens.fr				*/
 /* Minor modificatios for Linux by					*/
-/*	    Hannu Savolainen - hsavolai@cs.helsinki.fi			*/
+/*	    Hannu Savolainen - hannu@voxware.pp.fi			*/
 /* Command-line switches added by					*/
 /*	    Muhammad Saggaf - alsaggaf@erl.mit.edu			*/
 /*	    Leif Kornstaedt - l_kornst@informatik.uni-kl.de		*/
@@ -30,29 +30,27 @@
 #include <malloc.h>
 #include <unistd.h>
 #include <stdlib.h>
+#ifdef __STDC__
+#include <fcntl.h>
+#include <string.h>
+#else /* __STDC__ */
 #include <getopt.h>
 #include <fcntl.h>
 #include <strings.h>
+#endif /* __STDC__ */
 #include <errno.h>
 #include <sys/stat.h>
 
-#ifdef linux
 #include <sys/soundcard.h>
-#endif
-
 #include "str.h"
 
 /* output file name or dsp device */
 char AUDIO[256] = AUDIONAME;
 
-#ifdef linux
 int audio;			/* file handle */
 unsigned char *audiobuf;
 int abuf_size;
 int abuf_ptr;
-#else
-FILE *audio;
-#endif
 
 /* for analyzing the command line: */
 char *command;			/* the actual command name used (argv[0]) */
@@ -60,11 +58,9 @@ int loop_forever = FALSE;
 int quiet_mode = FALSE, verbose_mode = FALSE;
 static int use_zcat = FALSE;
 int mute[4] = { FALSE, FALSE, FALSE, FALSE };
-#ifdef linux
 int dsp_stereo = DSP_DEFAULT_STEREO;
 int dsp_samplesize = DSP_DEFAULT_SAMPLESIZE;
 long dsp_speed = DEFAULT_DSP_SPEED;
-#endif
 
 FILE *fp;
 
@@ -75,23 +71,16 @@ void
 usage(command)
 char *command;
 {
-#ifdef linux
     fprintf(stderr, "Usage: %s [ -cqvzS1234 -b size -s kHz -o output_file ] "
 	    "[ filename ... ]\n", command);
-#else
-    fprintf(stderr, "Usage: %s [-cqvz1234 -o output_file] "
-	    "[ filename ... ]\n", command);
-#endif
     fprintf(stderr, "\t-c\t\tplay infinitely\n"
 		    "\t-q\t\tquiet mode\n"
 		    "\t-v\t\tverbose mode\n"
 		    "\t-z\t\tuse zcat on file\n"
 		    "\t-1234\t\tmute voices 1, 2, 3 or 4\n"
-#ifdef linux
 		    "\t-S\t\ttoggle stereo\n"
 		    "\t-b size\t\tset sample size (8 or 16 bits)\n"
 		    "\t-s kHz\t\tuse sampling speed kHz\n"
-#endif
 		    "\t-o file\t\tredirect output to a file\n");
      exit(EXIT_FAILURE);
 }
@@ -142,11 +131,7 @@ char *argv[];
     command = argv[0];
 
     while((c = getopt(argc, argv,
-#ifdef linux
 				  "cqvz1234Sb:s:o:"
-#else
-				  "cqvz1234o:"
-#endif
 					      )) != EOF)
 	switch(c) {
 	case 'c':			/* play infinitely */
@@ -167,7 +152,6 @@ char *argv[];
 	case '4':
 	    mute[c - '1'] = TRUE;
 	    break;
-#ifdef linux
 	case 'S':			/* toggle stereo */
 	    dsp_stereo = !DSP_DEFAULT_STEREO;
 	    break;
@@ -179,7 +163,6 @@ char *argv[];
 	    if(dsp_speed < 300)
 		dsp_speed *= 1000;
 	    break;
-#endif
 	case 'o':			/* output file */
 	    strcpy(AUDIO, optarg);
 	    break;
@@ -190,7 +173,6 @@ char *argv[];
     /* output to a character device (TRUE) or a file (FALSE)? */
     outdev = !stat(AUDIO, &statbuffer) && S_ISCHR(statbuffer.st_mode);
 
-#ifdef linux
     if(!outdev)
 	opmode |= O_CREAT;		/* file: create it */
     if((audio = open(AUDIO, opmode, 0)) == -1) {
@@ -238,12 +220,6 @@ char *argv[];
 	exit(EXIT_FAILURE);
     }
     abuf_ptr = 0;
-#else
-    if((audio = fopen(AUDIO, "wb")) == NULL) {
-	fprintf(stderr, "%s: unable to access %s\n", command, AUDIO);
-	exit(EXIT_FAILURE);
-    }
-#endif
 
     if(optind > argc - 1) {
 	if(use_zcat) {
@@ -287,13 +263,9 @@ char *argv[];
 		}
 	    }
 
-#ifdef linux
     if(abuf_ptr)
 	write(audio, audiobuf, abuf_ptr);
     close(audio);
-#else
-    fclose(audio);
-#endif
 
     return EXIT_SUCCESS;
 }
