@@ -29,13 +29,19 @@
  */
 
 #ifndef PATCH_PATH
-#define PATCH_PATH "/E/ultrasnd/midi"
+#define PATCH_PATH "/dos/ultrasnd/midi"
 #endif
 
 #include <stdio.h>
 #include <sys/ultrasound.h>
+#include <sys/soundcard.h>
 #include <sys/ioctl.h>
+#ifdef __STDC__
+#include <string.h>
+#include <sys/soundcard.h>
+#else /* __STDC__ */
 #include <stdlib.h>
+#endif /* __STDC__ */
 #include <strings.h>
 #include <unistd.h>
 #include <fcntl.h>
